@@ -21,6 +21,7 @@
 """This module contains all exceptions raised by `OdooRPC` when an error
 occurred.
 """
+import sys
 
 
 class Error(Exception):
@@ -68,7 +69,10 @@ class RPCError(Error):
         ...         "'res.users' object has no attribute 'wrong_method'",           # >= 8.0
         ...         "type object 'res.users' has no attribute 'wrong_method'",      # >= 10.0
         ...     ]
-        ...     exc.info['data']['name'] == 'exceptions.AttributeError'
+        ...     exc.info['data']['name'] in [
+        ...         'exceptions.AttributeError',
+        ...         'builtins.AttributeError',
+        ...     ]
         ...
         True
         True
@@ -78,12 +82,25 @@ class RPCError(Error):
         True
     """
     def __init__(self, message, info=False):
+        # Ensure that the message is in unicode,
+        # to be compatible both with Python2 and 3
+        try:
+            message = message.decode('utf-8')
+        except (UnicodeEncodeError, AttributeError):
+            pass
         super(Error, self).__init__(message, info)
         self.info = info
 
     def __str__(self):
+        # args[0] should always be a unicode object (see '__init__(...)')
+        if sys.version_info[0] < 3 and self.args and self.args[0]:
+            return self.args[0].encode('utf-8')
         return self.args and self.args[0] or ''
 
+    def __unicode__(self):
+        # args[0] should always be a unicode object (see '__init__(...)')
+        return self.args and self.args[0] or u''
+
     def __repr__(self):
         return "%s(%s)" % (
             self.__class__.__name__,
