@@ -46,7 +46,21 @@ class ODOO(object):
     .. doctest::
         :options: +SKIP
 
-        >>> odoo = odoorpc.ODOO('localhost', version='10.0')
+        >>> odoo = odoorpc.ODOO('localhost', version='12.0')
+
+    You can also define a custom URL opener to handle HTTP requests. A use
+    case is to manage a basic HTTP authentication in front of `Odoo`:
+
+    .. doctest::
+        :options: +SKIP
+
+        >>> import urllib.request
+        >>> import odoorpc
+        >>> pwd_mgr = urllib.request.HTTPPasswordMgrWithDefaultRealm()
+        >>> pwd_mgr.add_password(None, "http://example.net", "userName", "passWord")
+        >>> auth_handler = urllib.request.HTTPBasicAuthHandler(pwd_mgr)
+        >>> opener = urllib.request.build_opener(auth_handler)
+        >>> odoo = odoorpc.ODOO('example.net', port=80, opener=opener)
 
     *Python 2:*
 
@@ -62,7 +76,7 @@ class ODOO(object):
     """
 
     def __init__(self, host='localhost', protocol='jsonrpc',
-                 port=8069, timeout=120, version=None):
+                 port=8069, timeout=120, version=None, opener=None):
         if protocol not in ['jsonrpc', 'jsonrpc+ssl']:
             txt = ("The protocol '{0}' is not supported by the ODOO class. "
                    "Please choose a protocol among these ones: {1}")
@@ -88,7 +102,7 @@ class ODOO(object):
         # Instanciate the server connector
         try:
             self._connector = rpc.PROTOCOLS[protocol](
-                self._host, self._port, timeout, version)
+                self._host, self._port, timeout, version, opener=opener)
         except rpc.error.ConnectorError as exc:
             raise error.InternalError(exc.message)
         # Dictionary of configuration options
@@ -153,7 +167,7 @@ class ODOO(object):
             :options: +SKIP
 
             >>> odoo.version
-            '10.0'
+            '12.0'
         """
         return self._connector.version
 
@@ -230,22 +244,25 @@ class ODOO(object):
             ...     {'db': DB, 'login': USER, 'password': PWD})
             >>> data['result']['db'] == DB
             True
-            >>> data['result']['uid'] == 1
+            >>> data['result']['uid'] in [1, 2]
             True
             >>> data['result']['username'] == USER
             True
 
         And a call to the ``read`` method of the ``res.users`` model:
 
-        >>> data = odoo.json(
-        ...     '/web/dataset/call',
-        ...     {'model': 'res.users', 'method': 'read',
-        ...      'args': [[1], ['name']]})
-        >>> from pprint import pprint
-        >>> pprint(data)
-        {'id': ...,
-         'jsonrpc': '2.0',
-         'result': [{'id': 1, 'name': 'Administrator'}]}
+        .. doctest::
+            :options: +SKIP
+
+            >>> data = odoo.json(
+            ...     '/web/dataset/call',
+            ...     {'model': 'res.users', 'method': 'read',
+            ...      'args': [[2], ['name']]})
+            >>> from pprint import pprint
+            >>> pprint(data)
+            {'id': ...,
+             'jsonrpc': '2.0',
+             'result': [{'id': 2, 'name': 'Mitchell Admin'}]}
 
         *Python 2:*
 
@@ -282,7 +299,7 @@ class ODOO(object):
         URL parameters (with :func:`urllib.urlencode` function for simple
         parameters, or multipart/form-data structure to handle file upload).
 
-        E.g., the HTTP raw query to get the company logo on `Odoo 10.0`:
+        E.g., the HTTP raw query to get the company logo on `Odoo 12.0`:
 
         .. doctest::
 
@@ -485,6 +502,9 @@ class ODOO(object):
         :raise: :class:`odoorpc.error.InternalError` (if not logged)
         :raise: `urllib.error.URLError` (connection error)
         """
+        if tools.v(self.version)[0] >= 11:
+            raise DeprecationWarning(
+                u"Workflows have been removed in Odoo >= 11.0")
         self._check_logged_user()
         # Execute the workflow query
         args_to_send = [self.env.db, self.env.uid, self._password,
