@@ -103,17 +103,19 @@ class ConnectorJSONRPC(Connector):
                                          'symbol': '$'}},
                     'db': 'db_name',
                     'is_admin': True,
-                    'is_superuser': True,
-                    'name': 'Administrator',
+                    'is_system': True,
+                    'name': 'Mitchell Admin',
+                    'partner_display_name': 'YourCompany, Mitchell Admin',
                     'partner_id': 3,
-                    'server_version': '10.0',
-                    'server_version_info': [10, 0, 0, 'final', 0, ''],
+                    'server_version': '12.0',
+                    'server_version_info': [12, 0, 0, 'final', 0, ''],
                     'session_id': '6dd7a34f16c1c67b38bfec413cca4962d5c01d53',
-                    'uid': 1,
+                    'show_effect': True,
+                    'uid': 2,
                     'user_companies': False,
                     'user_context': {'lang': 'en_US',
                                      'tz': 'Europe/Brussels',
-                                     'uid': 1},
+                                     'uid': 2},
                     'username': 'admin',
                     'web.base.url': 'http://localhost:8069',
                     'web_tours': []}}
@@ -131,6 +133,17 @@ class ConnectorJSONRPC(Connector):
         ...         'partner_id', 'server_version', 'server_version_info',
         ...         'user_companies', 'web.base.url', 'web_tours',
         ...     ])
+        >>> if v(VERSION) >= v('11.0'):
+        ...     keys.extend([
+        ...         'is_system',
+        ...     ])
+        ...     keys.remove('is_admin')
+        >>> if v(VERSION) >= v('12.0'):
+        ...     keys.extend([
+        ...         'partner_display_name',
+        ...         'show_effect',
+        ...     ])
+        ...     keys.remove('is_superuser')
         >>> all([key in data['result'] for key in keys])
         True
 
@@ -183,14 +196,16 @@ class ConnectorJSONRPC(Connector):
         True
     """
     def __init__(self, host, port=8069, timeout=120, version=None,
-                 deserialize=True):
+                 deserialize=True, opener=None):
         super(ConnectorJSONRPC, self).__init__(host, port, timeout, version)
         self.deserialize = deserialize
         # One URL opener (with cookies handling) shared between
         # JSON and HTTP requests
-        cookie_jar = CookieJar()
-        self._opener = build_opener(
-            HTTPCookieProcessor(cookie_jar))
+        if opener is None:
+            cookie_jar = CookieJar()
+            opener = build_opener(
+                HTTPCookieProcessor(cookie_jar))
+        self._opener = opener
         self._proxy_json, self._proxy_http = self._get_proxies()
 
     def _get_proxies(self):
@@ -206,7 +221,7 @@ class ConnectorJSONRPC(Connector):
             ssl=self.ssl, opener=self._opener)
         # Detect the server version
         if self.version is None:
-            result = proxy_json.web.webclient.version_info()['result']
+            result = proxy_json('/web/webclient/version_info')['result']
             if 'server_version' in result:
                 self.version = result['server_version']
         return proxy_json, proxy_http
@@ -250,8 +265,9 @@ class ConnectorJSONRPCSSL(ConnectorJSONRPC):
         ...     cnt = rpc.ConnectorJSONRPCSSL(HOST, port=PORT)
     """
     def __init__(self, host, port=8069, timeout=120, version=None,
-                 deserialize=True):
-        super(ConnectorJSONRPCSSL, self).__init__(host, port, timeout, version)
+                 deserialize=True, opener=None):
+        super(ConnectorJSONRPCSSL, self).__init__(
+            host, port, timeout, version, opener=opener)
         self._proxy_json, self._proxy_http = self._get_proxies()
 
     @property
